@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2000-2010 Erwin Waterlander
+Copyright (C) 2000-2011 Erwin Waterlander
 
 Ideas and source code of NCD (Ninux Czo Directory) have been
 used in the WCD graphical interface.
@@ -36,7 +36,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #include <stdio.h>
 #include <string.h>
 #include <signal.h>
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
 #ifndef __USE_XOPEN
 #define __USE_XOPEN
 #endif
@@ -56,6 +56,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #include "display.h"
 #include "wfixpath.h"
 #include "match.h"
+#ifdef WCD_UNICODE
+#  include "matchw.h"
+#else
+#  include "matchl.h"
+#endif
 #include "config.h"
 #ifdef WCD_USECURSES
 #include "colors.h"             /* add colors for the tree on MS platform */
@@ -106,7 +111,7 @@ struct wcdwin /* structure with window information */
    WINDOW *inputWin;
    dirnode curNode;
    char str[WCD_MAX_INPSTR];
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
    wchar_t wstr[WCD_MAX_INPSTR];
 #endif
    int mode;
@@ -190,7 +195,7 @@ char* getTreeLine(dirnode d, int y, int *y_orig, dirnode curNode, c3po_bool fold
    static text line = NULL;
    static text tline = NULL;
    dirnode n;
-   int i,len,clen;
+   size_t i,len,clen;
 
    if (d == NULL)
       return(NULL);
@@ -200,12 +205,12 @@ char* getTreeLine(dirnode d, int y, int *y_orig, dirnode curNode, c3po_bool fold
 
    if (line == NULL)
    {
-      line = textNewSize(WCD_GRAPH_MAX_LINE_LENGTH);
+      line = textNewSize((size_t)WCD_GRAPH_MAX_LINE_LENGTH);
       line[0] = '\0';
    }
    if (tline == NULL)
    {
-      tline = textNewSize(WCD_GRAPH_MAX_LINE_LENGTH);
+      tline = textNewSize((size_t)WCD_GRAPH_MAX_LINE_LENGTH);
       tline[0] = '\0';
    }
 
@@ -238,7 +243,7 @@ char* getTreeLine(dirnode d, int y, int *y_orig, dirnode curNode, c3po_bool fold
 
             strcat(tline,WCD_ONESUBDIR);
 
-            n = elementAtDirnode(0,d);
+            n = elementAtDirnode((size_t)0,d);
             if (fold eq true)
                tline[strlen(tline)-1] = '+';
 
@@ -269,7 +274,7 @@ char* getTreeLine(dirnode d, int y, int *y_orig, dirnode curNode, c3po_bool fold
 
                strcat(tline,WCD_SPLITDIR);
 
-               n = elementAtDirnode(0,d);
+               n = elementAtDirnode((size_t)0,d);
                if (fold eq true)
                   tline[strlen(tline)-1] = '+';
 
@@ -293,7 +298,7 @@ char* getTreeLine(dirnode d, int y, int *y_orig, dirnode curNode, c3po_bool fold
                if (y == *y_orig)
                {
                   strcat(tline,WCD_ENDDIR);
-                  n = elementAtDirnode(0,d);
+                  n = elementAtDirnode((size_t)0,d);
                   if (fold eq true)
                      tline[strlen(tline)-1] = '+';
                }
@@ -305,7 +310,7 @@ char* getTreeLine(dirnode d, int y, int *y_orig, dirnode curNode, c3po_bool fold
                if (y == *y_orig)
                {
                   strcat(tline,WCD_SUBDIR);
-                  n = elementAtDirnode(0,d);
+                  n = elementAtDirnode((size_t)0,d);
                   if (fold eq true)
                      tline[strlen(tline)-1] = '+';
                }
@@ -353,7 +358,7 @@ char* getTreeLine(dirnode d, int y, int *y_orig, dirnode curNode, c3po_bool fold
 
 void dumpTree(dirnode d)
 {
-   int index, size;
+   size_t index, size;
    dirnode n;
    int y;
    char *l;
@@ -418,7 +423,8 @@ void dumpTree(dirnode d)
 
 void setXYTree(dirnode d)
 {
-   int index, x, len, size;
+   size_t index, len, size;
+   int x;
    static int y;
    dirnode n;
 
@@ -432,7 +438,7 @@ void setXYTree(dirnode d)
       while(index < size)
       {
          n = elementAtDirnode(index,d);
-         x = dirnodeGetX(d) + len + 5;
+         x = dirnodeGetX(d) + (int)len + 5;
          dirnodeSetX(x,n);
          dirnodeSetY(y,n);
          setXYTree(n);
@@ -449,9 +455,9 @@ c3po_bool eqTextDirnode(text t, dirnode d)
    return(eqText(t,dirnodeGetName(d)));
 }
 
-int inDirnode(text t, dirnode d)
+size_t inDirnode(text t, dirnode d)
 {
-   int index, size;
+   size_t index, size;
 
    index = 0;
 
@@ -465,7 +471,7 @@ int inDirnode(text t, dirnode d)
          index++;
       }
    }
-   return -1;
+   return (size_t) -1;
 }
 
 void addPath(text path, dirnode d)
@@ -473,7 +479,7 @@ void addPath(text path, dirnode d)
    char *s;
    dirnode n,n_up;
    text t;
-   int index;
+   size_t index;
 #if (defined(WIN32) || defined(__CYGWIN__))
    static char buf[DD_MAXPATH] = "//" ;
 
@@ -496,7 +502,7 @@ void addPath(text path, dirnode d)
    if (s != NULL)
    {
       index = inDirnode(s,d);
-      if (index < 0)
+      if (index == (size_t) -1)
       {
          n = dirnodeNew(d,NULL,NULL);
          t = textNew(s);
@@ -520,7 +526,7 @@ void addPath(text path, dirnode d)
 
 void buildTreeFromNameset(nameset set, dirnode d)
 {
-   int i;
+   size_t i;
 
    if ((set == NULL)||(d == NULL))
       return;
@@ -604,7 +610,7 @@ dirnode searchNodeForDir(text path, dirnode d, dirnode rNode)
 {
    char *s;
    dirnode n;
-   int index;
+   size_t index;
    dirnode rootnode;
 #if (defined(WIN32) || defined(__CYGWIN__))
    static char buf[DD_MAXPATH] = "//" ;
@@ -639,7 +645,7 @@ dirnode searchNodeForDir(text path, dirnode d, dirnode rNode)
    if (s != NULL)
    {
       index = inDirnode(s,d);
-      if (index < 0)
+      if (index == (size_t) -1)
       {
          return(d);
       }
@@ -679,11 +685,11 @@ char *getNodeFullPath(dirnode node)
 
    if (line == NULL)
    {
-      line = textNewSize(DD_MAXPATH+1);
+      line = textNewSize((size_t)(DD_MAXPATH+1));
    }
    if (tline == NULL)
    {
-      tline = textNewSize(DD_MAXPATH+1);
+      tline = textNewSize((size_t)(DD_MAXPATH+1));
    }
 
    line[0] = '\0';
@@ -744,7 +750,7 @@ dirnode Right(dirnode node)
 {
 
    if(dirnodeFold(node) eq false)
-      return elementAtDirnode(0,node);
+      return elementAtDirnode((size_t)0,node);
    else
       return(NULL);
 }
@@ -818,7 +824,7 @@ dirnode getLastNodeInSameLevel(dirnode node)
    if (dirHasSubdirs(node) eq false)
       return(node);
    else
-      return getLastNodeInSameLevel(elementAtDirnode(0,node));
+      return getLastNodeInSameLevel(elementAtDirnode((size_t)0,node));
 }
 
 /******************************************************/
@@ -1140,7 +1146,7 @@ dirnode getNodeCursUpNatural(dirnode curNode, int graphics_mode)
 
 /******************************************************/
 
-int validSearchDir(char *dir, dirnode curNode, int exact, int ignore_case)
+int validSearchDir(char *dir, dirnode curNode, int exact, int ignore_case, int ignore_diacritics)
 {
    char path[WCD_MAX_INPSTR+2];
    char *name;
@@ -1164,9 +1170,15 @@ int validSearchDir(char *dir, dirnode curNode, int exact, int ignore_case)
       name = path + 1;
 
    /* matching with wildcard support !!! */
-   if ( (dd_match(dirnodeGetName(curNode),name,ignore_case)) &&
-        (dd_match(getNodeFullPath(curNode),path,ignore_case))
-         )
+   if (
+#ifdef WCD_UNICODE
+        (dd_matchmbs(dirnodeGetName(curNode),name,ignore_case,ignore_diacritics)) &&
+        (dd_matchmbs(getNodeFullPath(curNode),path,ignore_case,ignore_diacritics))
+#else
+        (dd_matchl(dirnodeGetName(curNode),name,ignore_case,ignore_diacritics)) &&
+        (dd_matchl(getNodeFullPath(curNode),path,ignore_case,ignore_diacritics))
+#endif
+      )
       return(1);
    else
       return(0);
@@ -1174,7 +1186,7 @@ int validSearchDir(char *dir, dirnode curNode, int exact, int ignore_case)
 
 /******************************************************/
 
-dirnode findDirInCiclePrev(char *dir, dirnode curNode, int exact, int ignore_case)
+dirnode findDirInCiclePrev(char *dir, dirnode curNode, int exact, int ignore_case, int ignore_diacritics)
 {
    dirnode node;
    int valid;
@@ -1183,7 +1195,7 @@ dirnode findDirInCiclePrev(char *dir, dirnode curNode, int exact, int ignore_cas
 
    do{
       node = prevNodeCiclic(node);
-      valid = validSearchDir(dir,node,exact,ignore_case);
+      valid = validSearchDir(dir,node,exact,ignore_case,ignore_diacritics);
    } while((!valid)&&(node!=curNode));
 
    return(node);
@@ -1191,7 +1203,7 @@ dirnode findDirInCiclePrev(char *dir, dirnode curNode, int exact, int ignore_cas
 
 /******************************************************/
 
-dirnode findDirInCicle(char *dir, dirnode curNode, int exact, int ignore_case)
+dirnode findDirInCicle(char *dir, dirnode curNode, int exact, int ignore_case, int ignore_diacritics)
 {
    dirnode node;
    int valid;
@@ -1200,7 +1212,7 @@ dirnode findDirInCicle(char *dir, dirnode curNode, int exact, int ignore_case)
 
    do{
       node = nextNodeCiclic(node);
-      valid = validSearchDir(dir,node,exact,ignore_case);
+      valid = validSearchDir(dir,node,exact,ignore_case,ignore_diacritics);
    } while((!valid)&&(node!=curNode));
 
    return(node);
@@ -1218,8 +1230,9 @@ dirnode findDirInCicle(char *dir, dirnode curNode, int exact, int ignore_case)
 void updateLine(WINDOW *win, dirnode n, int i, int y, dirnode curNode, int xoffset)
 {
    wcd_uchar *s;
-   int len, j;
-#ifdef WCD_UNICODE
+   size_t len;
+   int j;
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
    static wchar_t wstr[DD_MAXPATH];
    int width, c;
 #endif
@@ -1228,69 +1241,69 @@ void updateLine(WINDOW *win, dirnode n, int i, int y, dirnode curNode, int xoffs
 
    if (s != NULL)
    {
-#ifdef WCD_UNICODE
-      len = MBSTOWCS(wstr,(char *)s,DD_MAXPATH); /* number of wide characters */
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
+      len = MBSTOWCS(wstr,(char *)s,(size_t)DD_MAXPATH); /* number of wide characters */
 #else
       len = strlen((char *)s);
 #endif
       wmove(win,y,0);
-    /*  if (len <0 )
+    /*  if (len == (size_t) -1 )
       {
          fprintf(stderr,"len = %d\n",len);
          fprintf(stderr,"s = %s\n",s);
       } */
 
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
       /* xoffset is horizontal offset measured in nr. of columns. */
-      if (len < 0)
+      if (len == (size_t) -1)
       {
          /* Erroneous multi-byte sequence */
          /* Try 8 bit characters */
          len = strlen((char *)s);
-         for(j=xoffset;(j<len)&&((j-xoffset)<(COLS-1));j++)
+         for(j=xoffset;(j<(int)len)&&((j-xoffset)<(COLS-1));j++)
          {
             switch(s[j])
             {
                case WCD_ACS_HL:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '-');
+                  waddch(win, (chtype)'-');
                 else
                   waddch(win,ACS_HLINE);
                   break;
                case WCD_ACS_VL:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '|');
+                  waddch(win, (chtype)'|');
                 else
                   waddch (win,ACS_VLINE);
                   break;
                case WCD_ACS_LT:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '|');
+                  waddch(win, (chtype)'|');
                 else
                   waddch (win,ACS_LTEE);
                   break;
                case WCD_ACS_LLC:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '`');
+                  waddch(win, (chtype)'`');
                 else
                   waddch (win,ACS_LLCORNER);
                   break;
                case WCD_ACS_TT:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '+');
+                  waddch(win, (chtype)'+');
                 else
                   waddch (win,ACS_TTEE);
                   break;
                case WCD_SEL_ON:
                 wattron(win,A_REVERSE);
-                waddch(win,'['); /* square brackets indicate there was an error. */
+                waddch(win,(chtype)'['); /* square brackets indicate there was an error. */
                   break;
                case WCD_SEL_OFF:
-                waddch(win,']');
+                waddch(win,(chtype)']');
                 wattroff(win,A_REVERSE);
                   break;
                default:
-                waddch(win,s[j]);
+                waddch(win,(chtype)s[j]);
             }
          }
       }
@@ -1298,7 +1311,7 @@ void updateLine(WINDOW *win, dirnode n, int i, int y, dirnode curNode, int xoffs
       {
          c = 0; /* count width from beginning of string. */
          j = 0;
-         while ((j<len)&&(c<xoffset))
+         while ((j<(int)len)&&(c<xoffset))
          {
             switch(wstr[j])
             {
@@ -1325,10 +1338,10 @@ void updateLine(WINDOW *win, dirnode n, int i, int y, dirnode curNode, int xoffs
             j--;
             wstr[j] = ' ';
          }
-         while ((j<len)&&(wcwidth(wstr[j]) == 0 ))  /* Skip combining characters */
+         while ((j<(int)len)&&(wcwidth(wstr[j]) == 0 ))  /* Skip combining characters */
            j++;
          width = 0;
-         if (j<len)
+         if (j<(int)len)
             switch(wstr[j])
             {
                case WCD_ACS_HL:
@@ -1343,46 +1356,46 @@ void updateLine(WINDOW *win, dirnode n, int i, int y, dirnode curNode, int xoffs
                default:
                 width = wcwidth(wstr[j]);
             }
-         while ((j<len)&&(width<COLS))
+         while ((j<(int)len)&&(width<COLS))
          {
             switch(wstr[j])
             {
                case WCD_ACS_HL:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '-');
+                  waddch(win, (chtype)'-');
                 else
                   waddch(win,ACS_HLINE);
                   break;
                case WCD_ACS_VL:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '|');
+                  waddch(win, (chtype)'|');
                 else
                   waddch (win,ACS_VLINE);
                   break;
                case WCD_ACS_LT:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '|');
+                  waddch(win, (chtype)'|');
                 else
                   waddch (win,ACS_LTEE);
                   break;
                case WCD_ACS_LLC:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '`');
+                  waddch(win, (chtype)'`');
                 else
                   waddch (win,ACS_LLCORNER);
                   break;
                case WCD_ACS_TT:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '+');
+                  waddch(win, (chtype)'+');
                 else
                   waddch (win,ACS_TTEE);
                   break;
                case WCD_SEL_ON:
                 wattron(win,A_REVERSE);
-                waddch(win,'<');
+                waddch(win,(chtype)'<');
                   break;
                case WCD_SEL_OFF:
-                waddch(win,'>');
+                waddch(win,(chtype)'>');
                 wattroff(win,A_REVERSE);
                   break;
                default:
@@ -1406,50 +1419,50 @@ void updateLine(WINDOW *win, dirnode n, int i, int y, dirnode curNode, int xoffs
          }
       }
 #else
-      for(j=xoffset;(j<len)&&((j-xoffset)<(COLS-1));j++)
+      for(j=xoffset;(j<(int)len)&&((j-xoffset)<(COLS-1));j++)
       {
          switch(s[j])
          {
             case WCD_ACS_HL:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '-');
+                  waddch(win, (chtype)'-');
                 else
                   waddch(win,ACS_HLINE);
                break;
             case WCD_ACS_VL:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '|');
+                  waddch(win, (chtype)'|');
                 else
                   waddch (win,ACS_VLINE);
                break;
             case WCD_ACS_LT:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '|');
+                  waddch(win, (chtype)'|');
                 else
                   waddch (win,ACS_LTEE);
                break;
             case WCD_ACS_LLC:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '`');
+                  waddch(win, (chtype)'`');
                 else
                   waddch (win,ACS_LLCORNER);
                break;
             case WCD_ACS_TT:
                 if (wcd_cwin.graphics_mode & WCD_GRAPH_ASCII)
-                  waddch(win, '+');
+                  waddch(win, (chtype)'+');
                 else
                   waddch (win,ACS_TTEE);
                break;
             case WCD_SEL_ON:
                   wattron(win,A_REVERSE);
-                  waddch(win,'<');
+                  waddch(win,(chtype)'<');
                break;
             case WCD_SEL_OFF:
-                  waddch(win,'>');
+                  waddch(win,(chtype)'>');
                   wattroff(win,A_REVERSE);
                break;
             default:
-                  waddch(win,s[j]);
+                  waddch(win,(chtype)s[j]);
          }
       }
 #endif
@@ -1464,13 +1477,13 @@ void updateLine(WINDOW *win, dirnode n, int i, int y, dirnode curNode, int xoffs
 char *getZoomStackPath(dirnode stack)
 {
    static text line = NULL;
-   int i, size;
+   size_t i, size;
    text name;
 
 
    if (line == NULL)
    {
-      line = textNewSize(DD_MAXPATH);
+      line = textNewSize((size_t)DD_MAXPATH);
    }
 
    line[0] = '\0';
@@ -1482,7 +1495,7 @@ char *getZoomStackPath(dirnode stack)
       if(i != 0)
          strcat(line,"/");
       name = dirnodeGetName(elementAtDirnode(i,stack));
-      if((strlen(line)+strlen(name)) < DD_MAXPATH)
+      if((strlen(line)+strlen(name)) < (size_t)DD_MAXPATH)
          strcat(line,name);
    }
 
@@ -1497,7 +1510,7 @@ void dataRefresh(int ydiff, int init)
   static int xoffset = 0;  /* Horizontal offset in number of columns */
   static int yposition = -1;  /* -1 : not initialized */
   wcd_uchar *s;
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
   static wchar_t wstr[DD_MAXPATH];
   int width;
 #endif
@@ -1534,7 +1547,7 @@ void dataRefresh(int ydiff, int init)
 
   if (yoffset < 0) yoffset = 0;
 
-  len=dirnodeGetX(wcd_cwin.curNode)+str_columns(dirnodeGetName(wcd_cwin.curNode))+3;
+  len=dirnodeGetX(wcd_cwin.curNode)+(int)str_columns(dirnodeGetName(wcd_cwin.curNode))+3;
   /* len is total nr of colums of current node plus 3 */
   if (len > COLS)
   {
@@ -1554,26 +1567,26 @@ void dataRefresh(int ydiff, int init)
   for (i = 0; i < COLS; i++)
   {
     wmove(wcd_cwin.inputWin, 0, i);
-    waddch(wcd_cwin.inputWin, '-');
+    waddch(wcd_cwin.inputWin, (chtype)'-');
   }
 
   /* mvwprintw(inputWin, 1,0,"%s",getNodeFullPath(curNode)); */
   s = (wcd_uchar *)getZoomStackPath(wcd_cwin.zoomStack); /* s has size DD_MAXPATH */
   strcat((char *)s, getNodeFullPath(wcd_cwin.curNode));
-  wcd_fixpath((char *)s, DD_MAXPATH);
+  wcd_fixpath((char *)s, (size_t)DD_MAXPATH);
 
   if (s != NULL)
   {
     wmove(wcd_cwin.inputWin, 1, 0);
-#ifdef WCD_UNICODE
-   len = MBSTOWCS(wstr,(char *)s,DD_MAXPATH); /* number of wide characters */
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
+   len = (int)MBSTOWCS(wstr,(char *)s,(size_t)DD_MAXPATH); /* number of wide characters */
    if (len < 0)
    {
       /* Erroneous multi-byte sequence */
       /* Try 8 bit characters */
-      len = strlen((char *)s);
+      len = (int)strlen((char *)s);
       for (i = 0; (i < len) && (i < (COLS - 1)); i++)
-        waddch(wcd_cwin.inputWin, s[i]);
+        waddch(wcd_cwin.inputWin, (chtype)s[i]);
    } else {
       i = 0;
       width = wcwidth(wstr[i]);
@@ -1585,9 +1598,9 @@ void dataRefresh(int ydiff, int init)
       }
    }
 #else
-    len = strlen((char *)s);
+    len = (int)strlen((char *)s);
     for (i = 0; (i < len) && (i < (COLS - 1)); i++)
-      waddch(wcd_cwin.inputWin, s[i]);
+      waddch(wcd_cwin.inputWin, (chtype)s[i]);
 #endif
   }
 
@@ -1596,7 +1609,7 @@ void dataRefresh(int ydiff, int init)
   else
   {
     wmove(wcd_cwin.inputWin, 2, 0);
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
     waddstr(wcd_cwin.inputWin,_("SEARCH: "));
     waddnwstr(wcd_cwin.inputWin,wcd_cwin.wstr, WCD_MAX_INPSTR);
 #else
@@ -1632,12 +1645,14 @@ void showHelp(WINDOW *win, int height)
       wcd_mvwaddstr(win,13,0,_("u                 go half page up."));
       wcd_mvwaddstr(win,14,0,_("d                 go half page down."));
       wcd_mvwaddstr(win,15,0,_("t                 switch centered mode on/off."));
-      wcd_mvwaddstr(win,16,0,_("<Esc> or q        Abort."));
-      wcd_mvwaddstr(win,17,0,_("/                 Search forward."));
-      wcd_mvwaddstr(win,18,0,_("?                 Search backward."));
-      wcd_mvwaddstr(win,19,0,_("n                 Repeat latest / or ? search."));
-      wcd_mvwaddstr(win,20,0,_("<Enter>           Select directory."));
-      wcd_mvwaddstr(win,21,0,_("Press any key."));
+      wcd_mvwaddstr(win,16,0,_("T                 toggle between line drawing and ASCII characters."));
+      wcd_mvwaddstr(win,17,0,_("<Esc> or q        Abort."));
+      wcd_mvwaddstr(win,18,0,_("/                 Search forward."));
+      wcd_mvwaddstr(win,19,0,_("?                 Search backward."));
+      wcd_mvwaddstr(win,20,0,_("n                 Repeat latest / or ? search."));
+      wcd_mvwaddstr(win,21,0,_("<Enter>           Select directory."));
+      if (height > 22)
+        wcd_mvwaddstr(win,22,0,_("Press any key."));
 
       prefresh(win,0,0,0,0,height-1,COLS-1);
       getch();
@@ -1726,7 +1741,7 @@ dirnode popZoom(dirnode zoomStack, dirnode curNode, int *ymax)
    dirnode zlast;  /* element on zoom stack */
    dirnode top; /* the current top node */
    dirnode newtop; /* the new top node */
-   int size;
+   size_t size;
 
    if ((zoomStack == NULL)||(curNode == NULL))
       return(NULL);
@@ -1789,7 +1804,7 @@ void setFold(dirnode n, c3po_bool f, int *ymax)
  ****************************************************************/
 void setFold_tree(dirnode d, c3po_bool *f)
 {
-   int index,size;
+   size_t index,size;
    dirnode n;
 
    if(dirnodeHasSubdirs(d) eq true) /* only (un)fold directories that have subdirs */
@@ -1855,7 +1870,7 @@ void setFold_all(dirnode n, c3po_bool f, int *ymax)
  *****************************************************************/
 void condenseSubdirs(dirnode n, int *ymax)
 {
-   int i;
+   size_t i;
    dirnode d;
 
    if ((n == NULL)||(dirHasSubdirs(n) eq false))
@@ -1888,7 +1903,7 @@ void condense(dirnode n, int *ymax)
 
 #define Key_CTRL(x)      ((x) & 31)
 
-char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mode)
+char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mode,int ignore_diacritics)
 {
   int c = 0, n =0, y, ymax;
   int ydiff;
@@ -1897,7 +1912,7 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
 #ifndef __PDCURSES__
   SCREEN *sp;
 #endif
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
   wint_t ch;
 #endif
 
@@ -1910,7 +1925,7 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
 
    ptr=NULL;
 
-   getCurPath(curPath,DD_MAXPATH,use_HOME);
+   getCurPath(curPath, (size_t)DD_MAXPATH, use_HOME);
    wcd_cwin.curNode = locatePathOrSo(curPath,tree);
 
    wcd_cwin.zoomStack = dirnodeNew(NULL,NULL,NULL);
@@ -1974,7 +1989,7 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
    while (c != 13 )
    {
 
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
       c = get_wch(&ch);
 #else
       c = getch();
@@ -1982,7 +1997,7 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
       ydiff = wcd_cwin.curNode->y;
 
      if (wcd_cwin.mode == WCD_NAV)
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
      switch(ch)
 #else
      switch(c)
@@ -2075,12 +2090,12 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
          break;
       case 'p':
       case '#':
-            wcd_cwin.curNode = findDirInCiclePrev(dirnodeGetName(wcd_cwin.curNode),wcd_cwin.curNode,1,ignore_case);
+            wcd_cwin.curNode = findDirInCiclePrev(dirnodeGetName(wcd_cwin.curNode),wcd_cwin.curNode,1,ignore_case,ignore_diacritics);
          break;
       case ' ':
       case 'v':
       case '*':
-            wcd_cwin.curNode = findDirInCicle(dirnodeGetName(wcd_cwin.curNode),wcd_cwin.curNode,1,ignore_case);
+            wcd_cwin.curNode = findDirInCicle(dirnodeGetName(wcd_cwin.curNode),wcd_cwin.curNode,1,ignore_case,ignore_diacritics);
          break;
       case '/':
             wcd_cwin.mode = WCD_SEARCH;
@@ -2097,16 +2112,16 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
             if (n>1)
             {
                if (wcd_cwin.str[0] == '/')
-                  wcd_cwin.curNode = findDirInCicle(ptr2,wcd_cwin.curNode,0,ignore_case);
+                  wcd_cwin.curNode = findDirInCicle(ptr2,wcd_cwin.curNode,0,ignore_case,ignore_diacritics);
                else
-                  wcd_cwin.curNode = findDirInCiclePrev(ptr2,wcd_cwin.curNode,0,ignore_case);
+                  wcd_cwin.curNode = findDirInCiclePrev(ptr2,wcd_cwin.curNode,0,ignore_case,ignore_diacritics);
             }
          break;
       case ':':
             showHelp(wcd_cwin.scrollWin,wcd_cwin.scrollWinHeight);
          break;
       case 'q':
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
             ch = 3; /* 3 = Control-C */
 #else
             c = 3; /* 3 = Control-C */
@@ -2122,16 +2137,19 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
          break;
      case 8:  /* backspace */
      case KEY_BACKSPACE:
-            wcd_cwin.curNode = findDirInCiclePrev(dirnodeGetName(wcd_cwin.curNode),wcd_cwin.curNode,1,ignore_case);
+            wcd_cwin.curNode = findDirInCiclePrev(dirnodeGetName(wcd_cwin.curNode),wcd_cwin.curNode,1,ignore_case,ignore_diacritics);
      break;
       case 't':
                graphics_mode ^= WCD_GRAPH_CENTER ;
          break;
+      case 'T':
+               wcd_cwin.graphics_mode ^= WCD_GRAPH_ASCII ;
+         break;
      default:
      break;
      }
 
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
      switch(ch)
 #else
      switch(c)
@@ -2236,19 +2254,19 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
          wcd_cwin.curNode = getLastDescendant(wcd_cwin.curNode);
          break;
       case Key_CTRL ('p'):
-         wcd_cwin.curNode = findDirInCiclePrev(dirnodeGetName(wcd_cwin.curNode),wcd_cwin.curNode,1,ignore_case);
+         wcd_cwin.curNode = findDirInCiclePrev(dirnodeGetName(wcd_cwin.curNode),wcd_cwin.curNode,1,ignore_case,ignore_diacritics);
          break;
       case Key_CTRL ('v'):
-         wcd_cwin.curNode = findDirInCicle(dirnodeGetName(wcd_cwin.curNode),wcd_cwin.curNode,1,ignore_case);
+         wcd_cwin.curNode = findDirInCicle(dirnodeGetName(wcd_cwin.curNode),wcd_cwin.curNode,1,ignore_case,ignore_diacritics);
          break;
       case Key_CTRL ('n'):
          ptr2 = wcd_cwin.str + 1;
          if (n>1)
          {
             if (wcd_cwin.str[0] == '/')
-               wcd_cwin.curNode = findDirInCicle(ptr2,wcd_cwin.curNode,0,ignore_case);
+               wcd_cwin.curNode = findDirInCicle(ptr2,wcd_cwin.curNode,0,ignore_case,ignore_diacritics);
             else
-               wcd_cwin.curNode = findDirInCiclePrev(ptr2,wcd_cwin.curNode,0,ignore_case);
+               wcd_cwin.curNode = findDirInCiclePrev(ptr2,wcd_cwin.curNode,0,ignore_case,ignore_diacritics);
          }
          break;
       case KEY_F (1):
@@ -2275,7 +2293,7 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
             c = 13;
             ptr = getZoomStackPath(wcd_cwin.zoomStack); /* s has size DD_MAXPATH */
             strcat(ptr,getNodeFullPath(wcd_cwin.curNode));
-            wcd_fixpath(ptr,DD_MAXPATH);
+            wcd_fixpath(ptr, (size_t)DD_MAXPATH);
       break;
      case 8:  /* backspace */
      case KEY_BACKSPACE:
@@ -2283,7 +2301,7 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
                wcd_cwin.mode = WCD_NAV;
             if(n>1) n--;
             wcd_cwin.str[n] = '\0';
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
             wcd_cwin.wstr[n] = '\0';
 #endif
      break;
@@ -2293,19 +2311,19 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
                wcd_cwin.mode = WCD_NAV;
             if(n>1) n--;
             wcd_cwin.str[n] = '\0';
-#ifdef WCD_UNICODE
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
             wcd_cwin.wstr[n] = '\0';
 #endif
      break;
      default:
       if ((wcd_cwin.mode == WCD_SEARCH) && (n < WCD_MAX_INPSTR))
       {
-#ifdef WCD_UNICODE
-         wcd_cwin.wstr[n] = ch;
+#if defined(WCD_UNICODE) || defined(WCD_WINDOWS)
+         wcd_cwin.wstr[n] = (wchar_t)ch;
          n++;
          wcd_cwin.wstr[n] = '\0';
          /* Convert wide-character input string to byte string. Needed for searching. */
-         if (WCSTOMBS(wcd_cwin.str, wcd_cwin.wstr, WCD_MAX_INPSTR) < 0)
+         if (WCSTOMBS(wcd_cwin.str, wcd_cwin.wstr, (size_t)WCD_MAX_INPSTR) == (size_t)(-1))
          {
             n=1;
             wcd_cwin.str[n] = '\0';
@@ -2319,9 +2337,9 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
          if (n>1)
          {
             if (wcd_cwin.str[0] == '/')
-               wcd_cwin.curNode = findDirInCicle(ptr2,wcd_cwin.curNode,0,ignore_case);
+               wcd_cwin.curNode = findDirInCicle(ptr2,wcd_cwin.curNode,0,ignore_case,ignore_diacritics);
             else
-               wcd_cwin.curNode = findDirInCiclePrev(ptr2,wcd_cwin.curNode,0,ignore_case);
+               wcd_cwin.curNode = findDirInCiclePrev(ptr2,wcd_cwin.curNode,0,ignore_case,ignore_diacritics);
          }
       }
      break;
@@ -2348,7 +2366,7 @@ char *selectANode(dirnode tree, int *use_HOME, int ignore_case, int graphics_mod
          (*(ptr+1) != '/'))  /* UNC path */
       ptr++;
 #endif
-   wcd_fixpath(ptr,DD_MAXPATH);
+   wcd_fixpath(ptr, (size_t)DD_MAXPATH);
    return(ptr);
 
 }
