@@ -210,7 +210,7 @@ static uch match_CP1252[256] =
   0xf0, 0x6e, 0x6f, 0x6f, 0x6f, 0x6f, 0x6f, 0xf7, 0x6f, 0x75, 0x75, 0x75, 0x75, 0x79, 0xfe, 0x79
 };
 
-static uch match_ISO88591[256] =
+static uch match_CP28591[256] =  /* ISO-8859-1 */
 {
   0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
   0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f,
@@ -230,7 +230,7 @@ static uch match_ISO88591[256] =
   0xf0, 0x6e, 0x6f, 0x6f, 0x6f, 0x6f, 0x6f, 0xf7, 0x6f, 0x75, 0x75, 0x75, 0x75, 0x79, 0xfe, 0x79
 };
 
-static uch match_ISO88592[256] =
+static uch match_CP28592[256] =  /* ISO-8859-2 */
 {
   0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
   0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f,
@@ -287,11 +287,11 @@ int dd_matchl(const char *string,const char *pattern,int ignore_case, int ignore
           case 1252: /* Windows Latin-1 (Western European) */
             CPTable = match_CP1252;
             break;
-          case 8591: /* ISO Latin-1 (Western European) */
-            CPTable = match_ISO88591;
+          case 28591: /* ISO Latin-1 (Western European) */
+            CPTable = match_CP28591;
             break;
-          case 8592: /* ISO Latin-2 (Eastern European) */
-            CPTable = match_ISO88592;
+          case 28592: /* ISO Latin-2 (Eastern European) */
+            CPTable = match_CP28592;
             break;
           default: /* C */
             CPTable = match_C;
