@@ -65,7 +65,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include "dosdir.h"
 #include <string.h>
 #include <windows.h>
-//#include <strsafe.h>
+/* #include <strsafe.h> */
 #include "wcd.h"
 #include "display.h"
 
@@ -112,7 +112,7 @@ int doEnum( int level, NETRESOURCE *pnr, nameset n )
    HANDLE hEnum;
    DWORD count, bufsize, ui;
    NETRESOURCE buf[MAX_NR_BUF];
-   const char *type;
+   /* const char *type; */
    char path[DD_MAXPATH];
 
    rc = WNetOpenEnum( RESOURCE_GLOBALNET, RESOURCETYPE_DISK, 0, pnr, &hEnum );
@@ -144,20 +144,20 @@ int doEnum( int level, NETRESOURCE *pnr, nameset n )
          switch ( buf[ui].dwDisplayType )
          {
             case RESOURCEDISPLAYTYPE_DOMAIN:
-               type = "domain"; break;
+               /* type = "domain"; */ break;
             case RESOURCEDISPLAYTYPE_GENERIC:
-               type = "generic"; break;
+               /* type = "generic"; */ break;
             case RESOURCEDISPLAYTYPE_SERVER:
-               type = "server"; break;
+               /* type = "server"; */ break;
             case RESOURCEDISPLAYTYPE_SHARE:
-               type = "share";
+               /* type = "share"; */
                printf( "Wcd: %s\n", buf[ui].lpRemoteName );
                strncpy(path, buf[ui].lpRemoteName, DD_MAXPATH);
                wcd_fixpath(path, DD_MAXPATH);
                addToNamesetArray(textNew(path), n);
                break;
             default:
-               type = "unknown"; break;
+               /* type = "unknown"; */ break;
          }
          /* now we recurse if it's a container */
          if ( buf[ui].dwUsage & RESOURCEUSAGE_CONTAINER )
@@ -212,7 +212,7 @@ void wcd_getshares(char* path, nameset n)
 
       doEnum( 0, &nr, n );
    }
-   printf(_("Wcd: Found %d shared directories on server %s\n"), getSizeOfNamesetArray(n), path);
+   printf(_("Wcd: Found %lu shared directories on server %s\n"), (unsigned long)getSizeOfNamesetArray(n), path);
 }
 
 #endif
@@ -285,16 +285,16 @@ int wcd_isSharePath (char* path)
  * strings are encoded in UTF-8.
  */
 
-char *wcd_getcwd(char *buf, int size)
+char *wcd_getcwd(char *buf, size_t size)
 {
-   BOOL err;
+   DWORD err;
    DWORD dw; 
 #ifdef WCD_UNICODE
    static wchar_t wstr[DD_MAXPATH];
 
    err = GetCurrentDirectoryW(size, wstr);
    if ( err != 0)
-      if (wcstoutf8(buf, wstr, DD_MAXPATH) < 0)
+      if (wcstoutf8(buf, wstr, DD_MAXPATH) == (size_t)(-1))
          err = 0;
 #else
    err = GetCurrentDirectory(size, buf);
@@ -318,7 +318,7 @@ int wcd_chdir(char *buf, int quiet)
 #ifdef WCD_UNICODE
    static wchar_t wstr[DD_MAXPATH];
 
-   if (utf8towcs(wstr, buf, DD_MAXPATH) < 0)
+   if (utf8towcs(wstr, buf, DD_MAXPATH) == (size_t)(-1))
       err = 0;
    else
       err = SetCurrentDirectoryW(wstr);
@@ -331,7 +331,7 @@ int wcd_chdir(char *buf, int quiet)
       if ( !quiet )
       {
          dw = GetLastError(); 
-         fprintf(stderr,_("Wcd: error: Unable to change to directory %s: "), buf);
+         wcd_printf(_("Wcd: error: Unable to change to directory %s: "), buf);
          PrintError(dw);
       }
       return(1);   /* fail */
@@ -347,7 +347,7 @@ int wcd_mkdir(char *buf, int quiet)
 #ifdef WCD_UNICODE
    static wchar_t wstr[DD_MAXPATH];
 
-   if (utf8towcs(wstr, buf, DD_MAXPATH) < 0)
+   if (utf8towcs(wstr, buf, DD_MAXPATH) == (size_t)(-1))
       err = FALSE;
    else
       err = CreateDirectoryW(wstr, NULL);
@@ -362,7 +362,7 @@ int wcd_mkdir(char *buf, int quiet)
      if ( !quiet )
      {
        dw = GetLastError(); 
-       fprintf(stderr,_("Wcd: error: Unable to create directory %s: "), buf);
+       wcd_printf(_("Wcd: error: Unable to create directory %s: "), buf);
        PrintError(dw);
      }
      return(1);  /* fail */
@@ -376,7 +376,7 @@ int wcd_rmdir(char *buf, int quiet)
 #ifdef WCD_UNICODE
    static wchar_t wstr[DD_MAXPATH];
 
-   if (utf8towcs(wstr, buf, DD_MAXPATH) < 0)
+   if (utf8towcs(wstr, buf, DD_MAXPATH) == (size_t)(-1))
       err = FALSE;
    else
       err = RemoveDirectoryW(wstr);
@@ -391,7 +391,7 @@ int wcd_rmdir(char *buf, int quiet)
      if ( !quiet )
      {
        dw = GetLastError(); 
-       fprintf(stderr,_("Wcd: error: Unable to remove directory %s: "), buf);
+       wcd_printf(_("Wcd: error: Unable to remove directory %s: "), buf);
        PrintError(dw);
      }
      return(1);  /* fail */
@@ -424,7 +424,15 @@ int wcd_rmdir(char *buf, int quiet)
  ******************************************************************/
 int wcd_isdir(char *dir, int quiet)
 {
+
+#ifdef WCD_UTF16
+   static wchar_t wstr[DD_MAXPATH];
+   BOOL err;
+   DWORD dw; 
+   struct _stat buf;
+#else
    struct stat buf;
+#endif
    char *errstr;
    char tmp[DD_MAXDIR];
 
@@ -440,6 +448,42 @@ int wcd_isdir(char *dir, int quiet)
       else
          return(-1);
    } else {
+#ifdef WCD_UTF16
+      if (utf8towcs(wstr, dir, DD_MAXPATH) == (size_t)(-1))
+         err = FALSE;
+      else
+         err = TRUE;
+
+      if (err == TRUE)
+      {
+         if (_wstat(wstr, &buf) == 0)
+         {
+            if (S_ISDIR(buf.st_mode))
+               return(0);
+            else
+               return(-1);
+         }
+         else
+         {
+            if (!quiet)
+            {
+              errstr = strerror(errno);
+              wcd_printf("Wcd: %s: %s\n", dir, errstr);
+            }
+            return(-1);
+         }
+      }
+      else
+      {
+        if ( !quiet )
+        {
+          dw = GetLastError(); 
+          wcd_printf("Wcd: %s: ", dir);
+          PrintError(dw);
+        }
+        return(-1);  /* fail */
+      }
+#else
       if (stat(dir, &buf) == 0)
       {
          if (S_ISDIR(buf.st_mode))
@@ -456,6 +500,7 @@ int wcd_isdir(char *dir, int quiet)
          }
          return(-1);
       }
+#endif
    }
 }
 
@@ -506,14 +551,15 @@ int wcd_mkdir(char *buf, int quiet)
  * a volume manager. Replace the absolute volume path by $HOME.
  */
 
-char *replace_volume_path_HOME(char *buf, int size)
+char *replace_volume_path_HOME(char *buf, size_t size)
 {
    static char *home = NULL;      /* value of $HOME env variable */
    static char home_abs[DD_MAXPATH];  /* absolute volume path of $HOME */
    static char status = 0;
-   static int  len_home = 0;
-   static int  len_home_abs = 0;
-   int i, j, len_buf;
+   static size_t  len_home = 0;
+   static size_t  len_home_abs = 0;
+   size_t i, len_buf;
+   size_t j;
    char tmp[DD_MAXPATH];
    static char pattern[DD_MAXPATH];
    char *ptr1, *ptr2;
@@ -608,7 +654,7 @@ char *replace_volume_path_HOME(char *buf, int size)
 }
 #endif
 
-char *wcd_getcwd(char *buf, int size)
+char *wcd_getcwd(char *buf, size_t size)
 {
    char *err;
    char *errstr;
